@@ -11,7 +11,6 @@
         var service = {
             getResourceData: getResourceData,
             getPlaybookRun: getPlaybookRun,
-            getIriElement: getIriElement,
             getPlaybookActionExecuted: getPlaybookActionExecuted,
             getStatusByPicklistName: getStatusByPicklistName,
             getConfig: getConfig
@@ -39,16 +38,6 @@
             return defer.promise;
         }
 
-        function getIriElement(iri){
-            var defer = $q.defer();
-            $http.get(iri).then(function (response) {
-                defer.resolve(response);
-            }, function (error) {
-                defer.reject(error);
-            });
-            return defer.promise;
-        }
-
         function getPlaybookActionExecuted(queryObject) {
             var defer = $q.defer();
             var url = API.WORKFLOW + 'api/workflows/metrics/?&';
@@ -83,7 +72,7 @@
         }
         
         function getConfig() {
-            return $http.get('widgets/installed/socManagement-1.0.0/assets/socWidgetInput.json');
+            return $http.get('widgets/installed/socManagement-2.0.0/assets/socWidgetInput.json');
         }
     }
 })();
\ No newline at end of file
